#
# Create a grouped bar chart
#
# David Mathias
# February 2021
#

import random
import matplotlib.pyplot as plt
import numpy as np

# font sizes
LABELSIZE = 14
TICKSIZE = 12
TITLESIZE = 18


# function to label the bars with numeric values
def rect_num_labels(bars):
    for rect in bars:
        height = rect.get_height()
        plt.annotate('{}'.format(height),
                    xy=(rect.get_x() + rect.get_width() / 2, height),
                    xytext=(0, 3),  # 3 points vertical offset
                    textcoords='offset points', # set offset unit to points (rather than pixels)
                    ha='center', va='bottom')
    
    
def main():
    # labels for the bars
    conferences = ['ACC', 'Big 10', 'Big 12', 'Pac 12', 'SEC']
    # mapping conference names to number of teams
    size_map = {'ACC':15, 'Big 10':14, 'Big 12':14, 'Pac 12':12, 'SEC':14 }

    x_data = [i for i in range(5)]
    
    # randomly generate number of mammals
    mammals = [random.randint(2, 10) for _ in range(5)]
    # number of non-mammals = conference size - number of mammals
    other = [size_map[conferences[i]] - mammals[i] for i in range(5)]
    
    # set the figure size
    plt.figure(figsize=(8,6))
    
    # bar width
    width = 0.4
    # need a numpy array to allow subtraction in plt.bar call
    x = np.asarray(x_data)
    
    # pass the x locations and bar heights
    # pass a number of optional parameters
    #   edgecolor: use edge lines of this color (or colors)
    #   linewidth: width of edge lines
    #   color: color of bars in this group
    #   label: label to be used in legend
    rects1 = plt.bar(x - width/2, mammals, width, edgecolor='black', linewidth=1.5, color='yellow', label='Mammals')
    rects2 = plt.bar(x + width/2, other, width, edgecolor='black', linewidth=1.5, color='blue', label='Non-mammals')
    
    # place tick marks on both sides but tick labels on left side only
    plt.tick_params(axis='y', left=True, right=True, labelleft=True, labelright=False)
    # set tick labels
    plt.xticks(ticks=x_data, labels=conferences, fontsize=TICKSIZE)
    
    # create the legend and st font size
    plt.legend(fontsize=11)
    
    # call function to label the rectangles
    rect_num_labels(rects1)
    rect_num_labels(rects2)
    
    # axis labels and title
    plt.xlabel('Conference', fontsize=LABELSIZE)
    plt.ylabel('Mascot Count', fontsize=LABELSIZE)
    plt.title('NCAA Conference Mascot Counts by Type', fontsize=TITLESIZE)
    
    # save abd display plot
    plt.savefig('sample_plot_10.png', dpi=300)
    plt.show()

    
if __name__ == '__main__':
    main()
    