#
# Let's make our bar chart pretty
#
# David Mathias
# February 2021
#

import random
import matplotlib.pyplot as plt
import numpy as np

# font sizes
LABELSIZE = 14
TITLESIZE = 18


# function to label the bars with numeric values
def rect_labels(bars):
    for rect in bars:
        height = rect.get_height()
        plt.annotate('{}'.format(height),
                    xy=(rect.get_x() + rect.get_width() / 2, height),
                    xytext=(0, 3),  # 3 points vertical offset
                    textcoords="offset points",
                    ha='center', va='bottom')
    
    
def main():
    x_data = [i for i in range(6)]
    y_data = [random.randint(20, 100) for _ in range(6)]
    
    # labels for the bars
    x_labels = ['Hens', 'Bears', 'Buckeyes', 'Mocs', 'Eagles', 'Slugs']
    
    # colors for the bars
    bar_colors = ['blue', 'orange', 'lime', 'red', 'yellow', 'purple']
    

    # set the figure size
    plt.figure(figsize=(8,6))
    
    # pass the x locations and bar heights
    # pass a number of optional parameters
    #   tick_label: names for the bars
    #   color: one color for all bars or list of colors, one per bar
    #   edgecolor: use edge lines of this color (or colors)
    #   linewidth: width of edge lines
    rects = plt.bar(x_data, y_data, tick_label=x_labels, color=bar_colors, edgecolor='black', linewidth=1.5)
    
    # place tick marks on both sides but tick labels on left side only
    plt.tick_params(axis='y', left=True, right=True, labelleft=True, labelright=False)
    
    # call function to label the rectangles
    rect_labels(rects)
    
    # axis labels and title
    plt.xlabel('Mascot Name', fontsize=LABELSIZE)
    plt.ylabel('Degree of Ferociousness', fontsize=LABELSIZE)
    plt.title('Ferocity of College Mascots', fontsize=TITLESIZE)
    
    # save and display the plot
    plt.savefig('sample_plot_9.png', dpi=300)
    plt.show()

    
if __name__ == '__main__':
    main()
    