#
# Creates a catplot of average positional difference showing
# generalization of evolved thresholds.  Each violin represents a
# pair -- training path : testing path
#
# Takes data from the evolve_thresh_generalize files
#

import sys
import csv
import os
from copy import deepcopy
from random import randint
import statistics
import itertools

import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib.lines import Line2D
from matplotlib.patches import Patch
import seaborn as sns

plt.rcParams['pdf.fonttype'] = 42
plt.rcParams['ps.fonttype'] = 42

# color palette for plot
col_list = ['bright green', 'bright blue', 'bright red', 'bright orange', 
            'yellow', 'magenta', 'sage', 'cerulean', 'golden rod', 'bright pink']
# sns.palplot(sns.xkcd_palette(col_list))
plot_colors = sns.xkcd_palette(col_list)

TARGET_PATH_LEN = 1500

TITLESIZE = 18
LABELSIZE = 14
TICKSIZE = 12

ZIGZAG_W = False
CIRCLE_1 = False
SHUFFLE = False

# which data to plot:
#   diff: average positional difference
#   path: tracker path length
#   switch: average switches
DATA_TYPE = 'diff'


# dictionary mapping DATA_TYPE to index into data lines in file
indices = {'diff':3, 'path':2, 'switch':4}

# dictionary mapping DATA_TYPE to part of the plot title
title_datatype = {'diff': 'Average Postiional Difference', 'path': 'Path Length Difference', 'switch': 'Average Task Switches'}

# dictionary mapping DATA_TYPE to datatype name in output file name
filename_datatype = {'diff': 'diff', 'path': 'pathlen', 'switch': 'switch'}

# dictionary mapping DATA_TYPE to y-axis label
y_label = {'diff': 'Average Difference', 'path': 'Path Length Difference', 'switch': 'Average Task Switches'}

# lists for avg switches per run, directory number, intensity variation, response probability
# Because seaborn wants long data, dir_nums, ivs, and rps are repeated as necessary to match
# with the avg switch values
data_list = []   
train = []
test = []
num = []

datapath = '../datafiles_compiled/'
if CIRCLE_1:
    data_fn = open(datapath + 'evolve_thresh_generalize_circle-1.txt', 'r')
elif ZIGZAG_W:
    data_fn = open(datapath + 'evolve_thresh_generalize_zigzag-w.txt', 'r')
elif SHUFFLE:
    data_fn = open(datapath + 'shuffle_thresh_generalize_data.txt', 'r')
else:
    data_fn = open(datapath + 'evolve_thresh_generalize_data.txt', 'r')
    
lines = data_fn.readlines()

for line in lines:
    elts = line.split()
    train.append(elts[0])
    test.append(elts[1])
    if DATA_TYPE == 'path':
        data_list.append((float(elts[indices[DATA_TYPE]])) - TARGET_PATH_LEN)
    else:
        data_list.append(elts[indices[DATA_TYPE]])


x_data = np.asarray(train)
y_data = np.asarray(data_list).astype(np.float)
hues = np.asarray(test)

sns_dict = {y_label[DATA_TYPE]:y_data, 'Training Path':x_data, 'Test Path':hues}


# create a pandas DataFrame for seaborn to use
# sns_dict = {'Switches': switch_data, 'Data Set': x_data, 'Type': int_type}
plot_data = pd.DataFrame(sns_dict)

    
# uses a gray grid rather than white
sns.set(style='darkgrid')

sns.set_palette(plot_colors)

with sns.plotting_context('notebook', font_scale=1.5):
    cp = sns.catplot(x='Training Path', y=y_label[DATA_TYPE], hue='Test Path', data=plot_data, dodge=True, height=5, aspect=1.8) 


cp.fig.subplots_adjust(top=0.90, bottom=0.14, left=0.1)

title_part = title_datatype[DATA_TYPE]
filename_part = filename_datatype[DATA_TYPE]

if CIRCLE_1:
    title = title_part + ' -- Training on Circle1             '
    outfile = 'thresh_generalize_' + filename_part + '_circle-1_catplot.png'
elif ZIGZAG_W:
    title = title_part + ' Across Training : Testing Path Pairs           '
    outfile = 'thresh_generalize_' + filename_part + '_zigzag-w_catplot.png'
elif SHUFFLE:
    title = title_part + ' for Shuffled Evolved Thresholds            '
    outfile = 'thresh_generalize_' + filename_part + '_shuffle_catplot.png'
else:
    title = title_part + ' Across Training : Testing Path Pairs           '
    outfile = 'thresh_generalize_' + filename_part + '_catplot.png'

cp.fig.suptitle(title, fontsize=TITLESIZE)
plt.savefig(outfile, dpi=300)

plt.show()
